pub(crate) enum MediaFileError {
Sdk(Error),
File(Error),
NoSession,
}Expand description
All errors that can occur when downloading a media to a file.
Variants
Sdk(Error)
An error occurred when downloading the media.
File(Error)
An error occurred when writing the media to a file.
NoSession
We could not access the Matrix client via the Session.