pub(crate) struct FrameDimensions {
pub(crate) width: u32,
pub(crate) height: u32,
}Expand description
The dimensions of a frame.
Fields
width: u32The width of the frame.
height: u32The height of the frame.
Implementations
Sourceimpl FrameDimensions
Extensions to FrameDimensions for computing thumbnail dimensions.
impl FrameDimensions
Extensions to FrameDimensions for computing thumbnail dimensions.
Sourcepub(crate) fn thumbnail_max_dimensions(scale_factor: i32) -> Self
pub(crate) fn thumbnail_max_dimensions(scale_factor: i32) -> Self
Get the maximum dimensions for a thumbnail with the given scale factor.
Sourcefn with_texture(texture: &Texture) -> Option<Self>
fn with_texture(texture: &Texture) -> Option<Self>
Construct a FrameDimensions for the given texture.
Sourcepub(super) fn needs_thumbnail(
self,
thumbnail_dimensions: FrameDimensions,
) -> bool
pub(super) fn needs_thumbnail( self, thumbnail_dimensions: FrameDimensions, ) -> bool
Whether we should generate or request a thumbnail for these dimensions, given the wanted thumbnail dimensions.
Sourcepub(super) fn downscale_for(
self,
max_dimensions: FrameDimensions,
) -> Option<Self>
pub(super) fn downscale_for( self, max_dimensions: FrameDimensions, ) -> Option<Self>
Downscale these dimensions to fit into the given maximum dimensions while preserving the aspect ratio.
Returns None if these dimensions are smaller than the maximum
dimensions.
Sourcefn to_image_loader_request(self, requested: Self) -> FrameRequest
fn to_image_loader_request(self, requested: Self) -> FrameRequest
Convert these dimensions to a request for the image loader with the requested dimensions.
Sourceimpl FrameDimensions
impl FrameDimensions
Sourcepub(crate) fn from_options(
width: Option<UInt>,
height: Option<UInt>,
) -> Option<Self>
pub(crate) fn from_options( width: Option<UInt>, height: Option<UInt>, ) -> Option<Self>
Construct a FrameDimensions from the given optional dimensions.
Sourcepub(crate) fn dimension_for_orientation(self, orientation: Orientation) -> u32
pub(crate) fn dimension_for_orientation(self, orientation: Orientation) -> u32
Get the dimension for the given orientation.
Sourcepub(crate) fn dimension_for_other_orientation(
self,
orientation: Orientation,
) -> u32
pub(crate) fn dimension_for_other_orientation( self, orientation: Orientation, ) -> u32
Get the dimension for the other orientation than the given one.
Sourcepub(crate) fn ge(self, other: Self) -> bool
pub(crate) fn ge(self, other: Self) -> bool
Whether these dimensions are greater than or equal to the given dimensions.
Returns true if either width or height is bigger than or equal to
the one in the other dimensions.
Sourcepub(crate) const fn increase_by(self, value: u32) -> Self
pub(crate) const fn increase_by(self, value: u32) -> Self
Increase both of these dimensions by the given value.
Sourcepub(crate) const fn scale(self, factor: u32) -> Self
pub(crate) const fn scale(self, factor: u32) -> Self
Scale these dimensions with the given factor.
Sourcepub(crate) fn scale_to_fit(
self,
requested: Self,
content_fit: ContentFit,
) -> Self
pub(crate) fn scale_to_fit( self, requested: Self, content_fit: ContentFit, ) -> Self
Scale these dimensions to fit into the requested dimensions while preserving the aspect ratio and respecting the given content fit.